function [xf,yf,g] = cosxp2(x,y,T,perc);
% [xf,yf,tf] = cosxp2(x,y,t)
%   Expand grid using cosine taper mirror function, 
%   10% expansion. 
%   Adapted to vary the % expansion - try cosxp2(x,y,t,perc) where perc is a decimal 
%   that represents the expansion %, e.g. 0.2 --> 20% 

%Extension of the grid with half a cosine function
%Taken from Code for grid Euler using Differential Similarity transforms
%Written by: Daniela Gerovska and Marcos Arauzo-Bravo (27/February/2003) 

if ~exist('perc')
    perc=0.1;   % default exapnsion is 10%
end
perc = 1+perc;

[NumRow,NumCol]=size(T);
%Deciding NumRowExt NumColExt
%10 percent of the original number
NumRowExt=Eve10Ext(NumRow,perc);
NumColExt=Eve10Ext(NumCol,perc);

g=T;
%Extention of the grid with half a cosine function
% Cosine taper right side
s=0.5*(g(:,NumCol)+g(:,1));
r=0.5*(g(:,NumCol)-g(:,1));
lim=NumColExt-NumCol;
rlamb=lim+1;
arg=pi/rlamb;
for k=1:lim
    ge=s+r*cos(arg*k);
    g(:,NumCol+k)=ge;
end
g=g';
% size(g)
% Cosine taper upper side
s=0.5*(g(:,NumRow)+g(:,1));
r=0.5*(g(:,NumRow)-g(:,1));
lim=NumRowExt-NumRow;
rlamb=lim+1;
arg=pi/rlamb;
for k=1:lim
    ge=s+r*cos(arg*k);
    g(:,NumRow+k)=ge;
end
g=g';

%%% expanded coordinates - assume constant spacing in x and y 
dx = abs(x(2)-x(1));
xf = [min(x):dx:min(x)+(NumColExt-1)*dx];
yf = [min(y):dx:min(y)+(NumRowExt-1)*dx];


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function NumEveExt=Eve10Ext(Num,perc)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Even 10% extension of the number Num
%Written by: Daniela Gerovska and Marcos Arauzo-Bravo (27/February/2003) 
 
NumExt=perc*Num;
NumExtRou=round(NumExt);
if rem(NumExtRou,2)==1 
  DifPlu=abs(NumExt-(NumExtRou+1));
  DifMin=abs(NumExt-(NumExtRou-1));
    if DifPlu>DifMin
       NumEveExt=NumExtRou-1;
    else 
       NumEveExt=NumExtRou+1;
    end%if DifPlu>DifMin  
else
   NumEveExt=NumExtRou;   
end %if rem(NumExtRou,2)==1  

