function [t,x,y] = getcdf(file,Sampling,Dims);
% [t,x,y] = getcdf(file,Sampling,Dims);
%   Sampling is an integer where you can specify a desampling factor to get
%   a low res version of the data
%   Dims is an [Xmin Xmax Ymin Ymax] windowing option

CurrentVersion = version;

if CurrentVersion(1)=='6'
    
    if nargin<2
        Sampling=1;
    end
    if nargin<3
        Dims = {'1','end','1','end'};
    else
        % FIXME This isn't going to handle use of 'end' in the input 
        Dims={num2str(Dims(1)),num2str(Dims(2)),num2str(Dims(3)),num2str(Dims(4))};
    end
    
    varlist = n_filevars(file);
    XRange = [Dims{1},':',num2str(Sampling),':',Dims{2}];
    YRange = [Dims{3},':',num2str(Sampling),':',Dims{4}];
    [x]=use(file,varlist{1},varlist{1},XRange);
    [y]=use(file,varlist{2},varlist{2},YRange);
    [t]=use(file,varlist{3},varlist{1},XRange,varlist{2},YRange); 
    
elseif CurrentVersion(1)=='7'
    
    if nargin<2
        Sampling=1;
    end
    
    % Open the rotated grid
    ncid=netcdf.open(file,'NOWRITE');
    x = netcdf.getVar(ncid,0,'double');
    y = netcdf.getVar(ncid,1,'double');
    
    if nargin==3
        IndX = find(x>Dims(1)&x<Dims(2)); IndX=IndX(1:Sampling:end);
        IndY = find(y>Dims(3)&y<Dims(4)); IndY=IndY(1:Sampling:end);
        x = x(IndX); 
        y = y(IndY); 
        t = double(netcdf.getVar(ncid,2,[IndX(1)-1 IndY(1)-1],[length(IndX) length(IndY)],[Sampling Sampling]))';
    else
        x=x(1:Sampling:end);
        y=y(1:Sampling:end);
        t = netcdf.getVar(ncid,2,[0 0],[length(x) length(y)],[Sampling Sampling],'double')';
    end
    
    netcdf.close(ncid);
    
end