function [kx,ky] = kvalue(data,dx,dy)
% c  Subroutine KVALUE finds the wavenumber coordinates of one 
% c  element of a rectangular grid from subroutine FOURN.  
% c
% c  Input parameters:
% c    i  - index in the ky direction.
% c    j  - index in the kx direction.
% c    nx - dimension of grid in ky direction (a power of two).
% c    ny - dimension of grid in kx direction (a power of two).
% c    dkx - sample interval in the kx direction.
% c    dky - sample interval in the ky direction.
% c
% c  Output parameters:
% c    kx - the wavenumber coordinate in the kx direction.
% c    ky - the wavenumber coordinate in the ky direction.
% c
if nargin<3
    dy = dx;
end

[ny,nx] = size(data);
i=1:ny;
j=1:nx;
dkx = (2*pi)./(nx*dx);
dky = (2*pi)./(ny*dy);

nyqx=nx/2+1;
nyqy=ny/2+1;

ind = j<nyqx;
kx(ind)=(j(ind)-1).*dkx;
ind = j>=nyqx;
kx(ind)=(j(ind)-nx-1).*dkx;

ind = i<nyqy;
ky(ind)=(i(ind)-1).*dky;
ind = i>=nyqy;
ky(ind)=(i(ind)-ny-1).*dky;


    
    