function [gt bsmt] = Forward_NoThermalAndPressureCorrection(FAAGrid, BathyGrid, SedThickGrid, X, Y, phi0, c);
%       [gt bsmt] = Forward_NoThermalAndPressureCorrection(FAAGrid, BathyGrid, SedThickGrid, X, Y, phi0, c);
% c
% c  remove the gravity effect of seawater and sediment layer from free air
% c     anomaly
% c
% c  Input parameters:
% c    FAAGrid - free air gravity anomaly at the marin area, in mGal 
% c    BathyGrid - bathymetry grid, in km
% c    SedThickGrid - sediment grid, in km
% c    X - X cooridates for grid/3D model, in km. 
% c    Y - Y cooridates for grid/3D model, in km. 
% c    phi0 - paramter for the relationship between sediment porosity and
% c         buried depth, see Sawyer 1985
% c    c - paramter for the relationship between sediment porosity and
% c         buried depth, see Sawyer 1985
% c
% c  Output parameters:
% c    gt - the result of removing gravity effect of seawater and sediment layer from free air
% c        anomaly
% c    bsmt - basement interface, in km

%%
% deal with the wrong value in the sediment and bathymetry grid
SedThickGrid(SedThickGrid<0)=0;
SedThickGrid(isnan(SedThickGrid)) = 0;
BathyGrid(BathyGrid>0) = 0;

bsmt = -BathyGrid+SedThickGrid;
bsmt(BathyGrid==0) = 0; % focus on the marine area

% For gravity inversion codes, need distance units to all be in km
BathyGrid = BathyGrid./1000;
bsmt = bsmt./1000;


%% GRAVITY EFFECT OF WATER AND SEDIMENTS
% create surface of each layer in the 3D model, in km
layers = [0:50:14000,14100:100:20000,21000:1000:50000]./1000;

% calculate the gravity effect of seawater and sediment layer from free air anomaly
rhoBackground = 2700;
[gt,mv] = grav3dblock2(X,Y,-BathyGrid,bsmt,layers,phi0,c,rhoBackground);

%% result
gt=gt+FAAGrid;
Gmra = gt;

% % % Save all the results so far to a file
% % Topography=BathyGrid*1000;
% % save NoThermalCorrection_Sawyer1985
% % d = 9;