function [iAgeGrid] = MakeRegionalOCTGrid(X,Y,AgeGrid,s, continentAge)
%       [iAgeGrid] = MakeRegionalOCTGrid(X,Y,AgeGrid,s,proj, continentAge)
% c
% c  invert crustal thickness/Moho depth with different background density
% c       and reference depth, and get the RMS value for each background density
% c       and reference depth. The RMS will be used for choosing the best
% c       parameters for inversion
% c
% c  Input parameters:
% c    X - X cooridates for grid/3D model, in km. 
% c    Y - Y cooridates for grid/3D model, in km. 
% c    AgeGrid -oceanic crustal age, its value is null at the continent. 
% c    s - the boundary of transition area
% c    continentAge - the age of continent, it will be aligned to continent
% c       at the final age grid result (iAgeGrid)
% c
% c  Output parameters:
% c    iAgeGrid - crustal age grid after adding continental crustal age at
% c         the continet area and adding age at the transition area


[Xg,Yg] = meshgrid(X,Y);
%%
%age
Continent0TransitionGrid1Ocean2 = ones(size(Xg));


pX = s(2).X;
pY = s(2).Y;         
in = inpolygon(Xg,Yg,pX,pY);
Continent0TransitionGrid1Ocean2 = Continent0TransitionGrid1Ocean2 + in.*1;

pX = s(1).X;
pY = s(1).Y;         
in = inpolygon(Xg,Yg,pX,pY);
Continent0TransitionGrid1Ocean2 = Continent0TransitionGrid1Ocean2 + in.*1;


Continent0TransitionGrid1Ocean2 = Continent0TransitionGrid1Ocean2 - 1;


AgeGrid(Continent0TransitionGrid1Ocean2 == 0) = continentAge;
AgeGrid(Continent0TransitionGrid1Ocean2 == 1) = nan;

[GridX,GridY] = meshgrid(X,Y);
GridX = GridX(~isnan(AgeGrid));
GridY = GridY(~isnan(AgeGrid));
AgeGridPts = AgeGrid(~isnan(AgeGrid));
iAgeGrid = gridfit(GridX,GridY,AgeGridPts,X,Y);
